package com.ruoyi.system.mapper.fgw;

import java.util.List;
import com.ruoyi.system.domain.fgw.FgwJdapFj;

/**
 * 发改委_节点安排_附件Mapper接口
 * 
 * @author ruoyi
 * @date 2023-04-11
 */
public interface FgwJdapFjMapper 
{
    /**
     * 查询发改委_节点安排_附件
     * 
     * @param id 发改委_节点安排_附件主键
     * @return 发改委_节点安排_附件
     */
    public FgwJdapFj selectFgwJdapFjById(Long id);

    /**
     * 查询发改委_节点安排_附件列表
     * 
     * @param fgwJdapFj 发改委_节点安排_附件
     * @return 发改委_节点安排_附件集合
     */
    public List<FgwJdapFj> selectFgwJdapFjList(FgwJdapFj fgwJdapFj);

    /**
     * 新增发改委_节点安排_附件
     * 
     * @param fgwJdapFj 发改委_节点安排_附件
     * @return 结果
     */
    public int insertFgwJdapFj(FgwJdapFj fgwJdapFj);

    /**
     * 修改发改委_节点安排_附件
     * 
     * @param fgwJdapFj 发改委_节点安排_附件
     * @return 结果
     */
    public int updateFgwJdapFj(FgwJdapFj fgwJdapFj);

    /**
     * 删除发改委_节点安排_附件
     * 
     * @param id 发改委_节点安排_附件主键
     * @return 结果
     */
    public int deleteFgwJdapFjById(Long id);

    /**
     * 批量删除发改委_节点安排_附件
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteFgwJdapFjByIds(Long[] ids);

    void deleteFgwJdapFjByJdId(Long id);

    void deleteFgwJdapFjByJdIds(Long[] ids);
}
